@@ -1,10 +1,10 @@
 import os
 from pyPhases import Project
-from pyPhases.util.Logger import classLogger
+from pyPhases.util.Optionizable import Optionizable
+from pyPhases.Data import Data
 
 
-@classLogger
-class Phase:
+class Phase(Optionizable):
     name = ""
     config = {}
     metrics = {}
@@ -14,10 +14,17 @@ class Phase:
     runMethod = "main"
     project: Project = None
     exportData = []
+    exportDataStrings = []
     decorators = None
+    _prepared = False
 
-    def __init__(self, name = "undefined"):
-        self.name = name
+    def prepare(self):
+        if(self._prepared):
+            return
+        self.logDebug("Prepare phase: " + self.name)
+        self.exportData = list(map(lambda s: Data.create(s, self.project), self.exportData))
+        self.exportDataStrings = list(map(lambda data: data.name, self.exportData))
+        self._prepared = True
 
     def getDecorators(self):
         if not self.decorators == None:
@@ -30,11 +37,14 @@ class Phase:
 
         return self.decorators
 
+    def getData(self, name):
+        self.run()
+
     def run(self):
-        self.log("RUN Phase: " + self.name)
+        self.log("RUN phase: " + self.name)
 
         def methodNotFound():
-            self.logError("The Current Phase needs the followin method defined: " +
+            self.logError("The current phase needs the following method defined: " +
                       self.runMethod)
 
         method = getattr(self, self.runMethod, methodNotFound)
