@@ -1,20 +1,32 @@
 from ..util.Optionizable import Optionizable
 
 class DataExporter(Optionizable):
+    includesStorage: bool = False
+    recreate: bool = True
+
     """Checks an instance, if its type is compatible with the current Exporter
     """
     def checkType(self, check) -> bool:
         """ Checks an instance, if its type is compatible with the current Exporter
         """
-        pass
+        return False
 
-    def importData(self, raw):
+    def importData(self, raw, options = {}):
         """ this methods transforms raw data from the storage into a specific dataformat (defined by the exporter)
         """
-        pass
+        return raw
 
-    def export(self):
+    def export(self, data, options = {}):
 
         """ this method transforms a specific data type into a raw data that the storage can save
         """
-        pass
+        return data
+
+    def stream(self, data, options = {}):
+        raise Exception("The exporter has no stream method implemented")
+
+    def reinit(self):
+        if self.recreate:
+            return self
+        return type(self)(self.options)
+
