@@ -1,23 +1,23 @@
 from .DataExporter import DataExporter
-from pandas import DataFrame
 import pyarrow
-import pyarrow.feather as feather
 import numpy
 
 class ObjectExporter(DataExporter):
+    supportedTypes = []
+
     """ An Exporter that supports a lot of default formats using pyarrow"""
     def checkType(self, type):
-        return not hasattr(type, '__dict__') or type in (numpy.ndarray, tuple) or type in (DataFrame, tuple) or type in [DataFrame, numpy.ndarray]
+        return type in (str, int, bool, float, list, numpy.ndarray) or type in self.supportedTypes
         # TODO: more generic with ?!
 
-    def importData(self, byteString):
+    def importData(self, byteString, options = {}):
         context = pyarrow.default_serialization_context()
         buffer = pyarrow.py_buffer(byteString)
         df = context.deserialize(buffer)
 
         return df
 
-    def export(self, df):
+    def export(self, df, options = {}):
         context = pyarrow.default_serialization_context()
         serialized_df = context.serialize(df)
         buffer = serialized_df.to_buffer()
