@@ -1,4 +1,5 @@
-from .Storage import Storage, DataNotFound
+from .Storage import Storage
+from ..Data import DataNotFound
 
 
 class FileStorage(Storage):
