@@ -12,6 +12,7 @@ class LogLevel(Enum):
 class Logger():
     verboseLevel: LogLevel = LogLevel.INFO
 
+    @staticmethod
     def log(msg, system=None, level=LogLevel.INFO):
         if (system != None):
             msg = "[" + system + "] " + msg
@@ -26,18 +27,25 @@ class Logger():
 
 
 def classLogger(class_):
-    name = class_.__name__
 
     def log(self, msg, level=LogLevel.INFO):
-        Logger.log(msg, name, level)
+        system = type(self).__name__
+        Logger.log(msg, system, level)
 
     def logDebug(self, msg):
-        Logger.log(msg, name, level=LogLevel.DEBUG)
+        system = type(self).__name__
+        Logger.log(msg, system, level=LogLevel.DEBUG)
 
     def logWarning(self, msg):
-        Logger.log(msg, name, LogLevel.WARNING)
+        system = type(self).__name__
+        Logger.log(msg, system, LogLevel.WARNING)
+
+    def logError(self, msg):
+        system = type(self).__name__
+        Logger.log(msg, system, LogLevel.ERROR)
 
     class_.log = log
     class_.logDebug = logDebug
     class_.logWarning = logWarning
+    class_.logError = logError
     return class_
